function [z, p, es, el] = cmpmod(Y, As, Al);
%CMPMOD   Compare linear submodel versus larger one
%
%         [z,p, esub, e] = cmpmod(Y, Xsub, X)
%
%	  The standard hypothesis F-test of a regular linear model 
%	  against a smaller regular one.
%
%         Output parameters:
%            z		F-test statistic value
%            p		Prob(F variate > z)
%           esub	residus vector for the submodel
%           e		residus vector for the model
% 
%	  Input parameters:
%            Y		dependant variates vector
%            Xsub	controlled variates "X" matrix for the submodel
%	     X		controlled variates "X" matrix for the model
%
%	  See also LSFIT 

%       Anders Holtsberg, 27-07-95
%       Copyright (c) Anders Holtsberg

%	Revision 01-10-98 Mathematique Universite de Paris-Sud

n = length(Y);
ns = size(As,2);
nl = size(Al,2);
one = ones(n,1);
if any((one-As*(As\one))>10*eps)
   disp('Warning: perhaps you should include an intercept column of ones.')
end
if any(any((As-Al*(Al\As))>500*eps))
   disp('Warning: submodel not included in model, result is rubbish!')
end

ths = As\Y;
Ys = As*ths;
es = Y-Ys;

thl = Al\Y;
Yl = Al*thl;
el = Y-Yl;

Rs = sum(es.^2);
Rl = sum(el.^2);

z = ((Rs-Rl)/(nl-ns)) ./ (Rl/(n-nl));

p = 1-pf(z, nl-ns, (n-nl));
