function d = dbeta(x,a,b)
%DBETA    The beta density function
%
%         f = dbeta(x,a,b)
%	Input	x	real
%		a,b	positive reals
%		(x,a,b can be matrix with common dimensions)
%
%	Output	f	beta density function with parameters a and b at 
%			the values of x :
%			f=x.^(a-1) .* (1-x).^(b-1) ./ beta(a,b)1_{0<x<1}

%       Anders Holtsberg, 18-11-93
%       Copyright (c) Anders Holtsberg

%	Revision 31-10-98 Mathematique Universite de Paris-Sud

if any(any((a<=0)|(b<=0)))
   error('Parameter a or b is nonpositive')
end

I = find((x<0)|(x>1));

d = x.^(a-1) .* (1-x).^(b-1) ./ beta(a,b);
d(I) = 0*I;
