function f = df(x,a,b)
%DF       The F density function (or Fisher-Snedecor density function)
%
%   f = df(x,df1,df2)
%	Input	x	real (scalar, vector or matrix)
%		df1,df2	degrees of freedom
%
%	Output	f	F density function at the value of x, of 
%			(X/df1)/(Y/df2) where X and Y are independent 
%			Chi-square variables with one degree of freedom

%        Anders Holtsberg, 18-11-93
%        Copyright (c) Anders Holtsberg

%	Revision 31-10-98 Mathematique Universite de Paris-Sud

if any(any(a<=0 | b<= 0)) 
   error('Degrees of freedom is wrong')
end
c = b./a;
xx = x./(x+c);
f = dbeta(xx,a/2,b/2);
f = f./(x+c).^2.*c;

