function  p = dhypg(k,n,K,N)
%DHYPG  The hypergeometric probability function
%
%        p = dhypg(k,n,K,N)
%	Input	n,K,N 	nonnegative integers such that n<= N, K<= N 		
%           	k 	integer	
%		(N is the total number of elements of the population
%		 n is the number of elements which are randomly
%	           extracted
%		 K is the number of elements of the population which 
%		   have the studied property)
%
%	Output  p	probability Prob(X=k) where X is an hypergeometric
%			random variable with parameters n,K,N

%       Anders Holtsberg, 18-11-93
%       Copyright (c) Anders Holtsberg

%	Revision 31-10-98 Mathematique Universite de Paris-Sud


if any(any(round(n)~=n | round(N)~=N |round(k)~=k |round(K)~=K))
    error('requires integer arguments');
end
if any(any( n>N | K>N | K<0 ));
   error('Incompatible input arguments');
end

z = k<0 | n-k<0 | k>K | n-k>N-K;
i = find(~z);
if length(k)>1, k = k(i); end
if length(K)>1, K = K(i); end
if length(n)>1, n = n(i); end
if length(N)>1, N = N(i); end
%pp = bincoef(k,K) .* bincoef(n-k,N-K) ./ bincoef(n,N);
pp = gammaln(K+1) - gammaln(k+1) - gammaln(K-k+1);
pp = pp + gammaln(N-K+1) - gammaln(n-k+1) - gammaln(N-K-n+k+1);
pp = pp - gammaln(N+1) + gammaln(n+1) + gammaln(N-n+1);
pp = exp(pp);
p = z*0;
p(i) = pp(:);
