function p = loddsinv(z,b)
%LODDSINV Compute the inverse of log odds.
%
%	  p = loddsinv(z,b)
%
%	  The function is equal to 1/(1+exp(-u)) with 
%              u = z if only one input argument is given
%              u = z*b if size(z,2) = length(b)
%	       u = z*b(1:n-1) + b(n) if size(z,2) < length(b)

%       Anders Holtsberg, 14-12-94
%       Copyright (c) Anders Holtsberg

if nargin>1
   X = z;
   n = length(b);
   if size(X,2) < n
      z = b(n) + X*b(1:n-1);
   else
      z = X*b;
   end
end
p = 1 ./ (1+exp(-z));
