function J = pairs(X,plotsymbol,diagonal)
%PAIRS    Pairwise scatter plots.
%
%	  pairs(X)
%         pairs(X,plotsymbol,diagonal)
%
%	  The columns of X are plotted versus each other. An optional
%	  second argument is plotting symbol and a third argument is
%	  1 (2) if only upper (lower) triangle should be plotted.

%       Anders Holtsberg, 14-12-94
%       Copyright (c) Anders Holtsberg

clf
[n,p] = size(X);
X = X - ones(n,1)*min(X);
X = X ./ (ones(n,1)*max(X));
if nargin<3
   diagonal = 0;
end
if nargin<2
   if n*p<100, plotsymbol = 'o';
   else plotsymbol = '.';
   end
end
bf = 0.1;
ffs = 0.05/(p-1);
ffl = (1-2*bf-0.05)/p;
fL = linspace(bf,1-bf+ffs,p+1);
for i = 1:p
   for j = 1:p
      if diagonal == 0 | (diagonal == 1 & j<=i) | (diagonal == 2 & j>=i)
         h = axes('position',[fL(i),fL(p+1-j),ffl,ffl]);
         if i==j
            histo(X(:,i))
            set(gca,'XLim',[-0.1 1.1])
         else
            plot(X(:,i),X(:,j),plotsymbol)
            axis([-0.1 1.1 -0.1 1.1])
         end
         set(gca,'XTickLabels',[],'XTick',[]);
         set(gca,'YTickLabels',[],'YTick',[]);
         if i==1
            ylabel([num2str(j),' '],'Rotation',0)
         end
         if j==1
            title(num2str(i))
         end
         drawnow
      end
   end
end
