function F = pbeta(x,a,b)
%PBETA    The beta distribution function
%
%         F = pbeta(x,a,b)
%	Input	x	matrix (elements between 0 and 1)
%		a,b	positive reals, parameters of the beta distribution
%		(x,a,b  can be scalar or matrix with common size)
%
%	Output	F	for each element of x, F=Prob(X<x) where X is a  
%			random variable with beta density :
%			x--> x.^(a-1) .* (1-x).^(b-1) ./ beta(a,b)1_{0<x<1}

%       Anders Holtsberg, 18-11-93
%       Copyright (c) Anders Holtsberg

%	Revision 31-10-98 Mathematique Universite de Paris-Sud

if any(any((a<=0)|(b<=0)))
   error('Parameter a or b is nonpositive')
end

Ii = find(x>0&x<1);
Il = find(x<=0);
Iu = find(x>=1);
F = 0*(x+a+b); % Stupid allocation trick
F(Il) = 0*Il;
F(Iu) = 0*Iu + 1;
if length(Ii) > 0 
   F(Ii) = betainc(x(Ii),a,b);
end

