function  p = phypg(k,n,K,N)
%PHYPG  The hypergeometric cumulative probability function
%
%	p = phypg(k,n,K,N)
%	Input	k	integers (scalar, vector or matrix)
%		n,K,N   nonnegative integers such that 
%			n<= N and K<= N
%		N 	is the total number of elements of the population
%		n 	is the number of elements which are randomly
%		 	extracted
%		K 	is the number of elements of the population which 
%			  have the studied property
%
%	Output  p	for each k, p is the probability Prob(X<=k) where
%			X is an hypergeometric random variable with 
%			parameters n,K,N


%       Anders Holtsberg, 18-11-93
%       Copyright (c) Anders Holtsberg

%	Revision 31-10-98 Mathematique Universite de Paris-Sud

if max([length(n) length(K) length(N)]) > 1
   error('Sorry, this is not implemented');
end

kk = -1:n;
cdf = cumsum(dhypg(kk,n,K,N));
cdf(n+2) = 1;
p = k;
p(:) = cdf(max(1,min(n+2,floor(k(:))+2)));

