function x=rexpweib(n,l,a)
%REXPWEIB   Random numbers from the exponential or weibull distributions
%
%         x=rexpweib(n,l,a)
%       Input    n  positive integer or vector [lig,col] of integers
%                l  positive real
%                a  Weibull parameter (default a=1: exponential dist.)
%
%       Output   x  n-vector of random numbers
%                   chosen from a weibull distribution 
%                            (F(x) = 1-exp[-(l*x)^a])
%

%	Revision 31-10-98 Mathematique Universite de Paris-Sud
%
if nargin<2 | nargin>3
   error('Wrong number of input parameters')
   return
end
   
if nargin==2
   a=1;
end

if length(n)==1
   n=[n 1];
end
            
if length(n)~=2 | length(l)>1 | length(a)>1 
   error('Wrong input parameter type')
   return
end

if l<0 | a<=0
   error('Wrong input parameter value')
   return
end   

x=-log(rand(n));
x=x.^(1/a)/l;
