function  m = rbinom(num,n,p)
%RBINOM  Random numbers from the binomial distribution (reject method)
%
%        x = rbinom(num,n,p)
%	Input	num	positive integer or vector [lig,col] of integers
%		n	nonnegative integer 
%		p	probability (scalar)
%	Output	x	vector or matrix of random numbers 
%			chosen from binomial distribution B(n,p)

%       Adapted from Press, Teukolsky, Vetterling
%       and Flannery, Numerical Recipes in C p.220

%	Revision 01-10-98 Mathematique Universite de Paris-Sud

if nargin~=3
   error('Wrong number of input parameters')
   return
end

if length(num)==1
   num=[num 1];
end

if length(num)~=2 | length(n)>1 | length(p)>1
   error('Wrong input parameter type')
   return
end

if n<1 | p<0 | p>1
   error('Wrong input parameter value')
   return 
end

if p>.5
    pp=p;
else    
    pp=1-p;
end

mean=n*pp;
sq=sqrt(2*mean*(1-pp));
g=gammaln(n+1);
plog=log(pp);
qlog=log(1-pp);
              

if(n<25)
    m=zeros(num);
    for j=1:n
        m=m+(rand(num)<pp);      
    end     
else
    m=zeros(num);
    t=m;
    while any(1-t)==1
        y=tan(pi*rand(num));
        mm=sq*y+mean;
        uu=(mm>=0).*(mm<=n+1);
        mm=floor(mm).*uu;
        tt=1.2*sq*(1+y.*y).*exp(g-gammaln(mm+1)-gammaln(n-mm+1)+plog*mm+qlog*(n-mm))-rand(num); 
        t1=uu.*(tt>0);
        m=m+mm.*(t1>t);
        t=max(t,t1); 
    end
end               
      
if p~=pp
     m=n-m;
end
    