function x=rjgamma(n,a);
%RJGAMMA     Generates gamma random deviates (reject method)
%           x=rjgamma(n,a)
%	Input	n	positive integer or vector [lig,col] of integers
%               a       positive real
%
%       Output  x       n-vector of random numbers
%                       chosen from gamma distribution with parameter a

% GKS 31 July 93

% Algorithm for A >= 1 is Best's rejection algorithm XG
% Adapted from L. Devroye, "Non-uniform random variate
% generation", Springer-Verlag, New York, 1986, p. 410.

% Algorithm for A < 1 is rejection algorithm GS from
% Ahrens, J.H. and Dieter, U. Computer methods for sampling
% from gamma, beta, Poisson and binomial distributions.
% Computing, 12 (1974), 223 - 246.  Adapted from Netlib
% Fortran routine.

%	Revision 01-10-98 Mathematique Universite de Paris-Sud

if nargin~=2
   error('Wrong number of input parameters')
   return
end

if length(n)==1
   n=[n 1];
end

if length(n)~=2 | length(a)>1
   error('Wrong input parameter type')
   return
end

if a<=0
   error('Wrong input parameter value')
   return
end
            
x=zeros(n);
accept=x;

if a>=1

  b=a-1;
  c=3*a-0.75;
  while any(1-accept)==1
       u=rand(n);
       w=u.*(1-u);
       y=sqrt(c./w).*(u-0.5);
       gam=b+y;
       z=64.*w.^3.*rand(n).^2;
       acc=(z<=(1-2.*y.^2./gam));
       if a==1,
            accept1=(gam>=0).*(acc+(1-acc).*(log(z)<=-2*y));
       else
            accept1=(gam>=0).*(acc+(1-acc).*(log(z)<=2*(b*log(gam/b)-y)));
       end
       change=(accept1>accept); % =1 si et si seulement 1 > 0
       x=x+gam.*change;
       accept=max(accept,accept1);  
  end   

else

  b=1+.3678794*a;
  while any(1-accept)==1,
       p=b*rand(n);
       u=-log(rand(n));
       gam=(p<1).*exp(log(p)/a)-(p>=1).*log((b-p)/a);
       accept1=(p<1).*(u>=gam) +(p>=1).*(u>=(1-a)*log(gam));

       x=x+gam.*(accept1>accept);  
       accept=max(accept1,accept);
  end

end
