function x=rjpoiss(n,l)
%RJPOISSON   Random numbers from the poisson distribution (reject method)
%
%         x=rjpoiss(n,l)
%       Input    n  positive integer or vector [lig,col] of integers
%                l  positive real
%
%       Output   x  n-vector of random numbers
%                   chosen from a poisson distribution with parameter l
%

%       Adapted from Press, Teukolsky, Vetterling
%       and Flannery, Numerical Recipes in C p.222

%	Revision 01-10-98 Mathematique Universite de Paris-Sud

if nargin~=2
   error('Wrong number of input parameters')
   return
end

if length(n)==1
   n=[n 1];
end

if length(n)~=2 | length(l)>1
   error('Wrong input parameter type')
   return
end
%
if n<1 | l<=0 
   error('Wrong input parameter value')
   return 
end

g=l*log(l)-gammaln(l+1);

x=zeros(n);
t=x;
while any(1-t)==1
     v=tan(pi*rand(n));
     y=v*sqrt(2*l)+l;
     u=(y>0);
     y=floor(y).*u;
     t1=( 0.9*(1+v.*v).*exp(y*log(l)-gammaln(y+1)-g) > rand(n) ).*u;
     x=x+y.*(t1>t);
     t=max(t,t1);
end

