function x=rpoiss(n,l)
%RPOISS   Random numbers from the poisson distribution (renewal method)
%
%         x=rpoiss(n,l)
%       Input    n  positive integer or vector [lig,col] of integers
%                l  positive real
%
%       Output   x  vector or matrix of random numbers
%                   chosen from a poisson distribution with parameter l
%

%	Revision 01-10-98 Mathematique Universite de Paris-Sud

if nargin~=2
   error('Wrong number of input parameters')
   return
end

if length(n)==1
   n=[n 1];
end

if length(n)>2 | length(l)>1
   error('Wrong input parameter type')
   return
end

if l<=0 
   error('Wrong input parameter value')
   return 
end

s=zeros(n);
x=s;
t=ones(n);
while any(t)
   s=s+t.*rexpweib(n,1);
   x=x+t;
   t=(s<l);
end
x=x-ones(n);
