%
%STIXDEMO Demonstrate various stixbox routines.

%       Anders Holtsberg, 25-11-94
%       Copyright (c) Anders Holtsberg

%	Revision 01-10-98 Mathematique Universite de Paris-Sud

clf reset
echo on
clc
%	==========================================================
%	STIXDEMO
%	Let us start with some data, for example a small correlated 
%	two dimensional sample with some weird underlying distri-
%	bution.
%	==========================================================

n = 20;	
Y = rchisq(n,3);
X = Y + 3*rand(n,1);

pause % Strike any key to continue.
clc
%	==========================================================
%	IDENTIFY
%	The first thing to do with any data material is to plot it
%	and look at syspicious observations. Now, identify the 
%	numbers of some interesting observations by clicking with 
%	the left mouse button on them. Quit by clicking with 
%	another mouse button or press the space bar.
%	==========================================================

identify(X,Y,'o')

pause % Strike any key to continue.
clc
%	==========================================================
%	LINEAR REGRESSION
%	A standard linear regression looks like this.
%	You may identify observations here too.
%	Click with the mouse. End with middle button.
%	==========================================================

X = randn(30,1);
Y = 2 + 3*X + randn(30,1); 
clf
linreg(Y,X);
grid	
hold on
identify(X,Y, [])
hold off

pause % Strike any key to continue. 
clc
%	==========================================================
%	POLYNOMIAL REGRESSION
%	Exactly the same as last picture but now a second degree
%	fit instead. Click with the mouse. End with middle button.
%	==========================================================

Y = 2 + 2*X + 1*X.^2 + randn(30,1); 
clf
linreg(Y,X, 0.9, [], 2);
grid	
hold on
identify(X,Y, [])
hold off

pause % Strike any key to continue. 
clc
%	==========================================================
%	DATA METERIALS
%
%	There are some data materials included.
%	==========================================================

x = getdata;

if size(x,2)<2 
     plot(x(:,1),'o')
else plot(x(:,1),x(:,2),'o')
end

pause % Strike any key to continue. 
clc
%	==========================================================
%	FANCY PLOTTING
%	1. Plot with different symbols
%	==========================================================

clf
m = 12;
x = [randn(m,1); randn(m,1)+2; randn(m,1)+4];
y = [randn(m,1); randn(m,1)+4; randn(m,1)+3];
s = ones(m,1)*[1 2 3];
s = s(:);

plotsym(x,y,s,'stc','k')

pause % Strike any key to continue. 
clc
%	==========================================================
%	FANCY PLOTTING
%	2. Plot with different colors
%	==========================================================

z = (1:3*m)';

plotsym(x,y,s,'stc',z)

colormap(hot)

pause % Strike any key to continue. 
clc
%	==========================================================
%	FANCY PLOTTING
%	3. Plot with different sizes instead
%	==========================================================

z = z/max(z)*5;

plotsym(x,y,s,'stc','k',z)

pause % Strike any key to continue. 
clc
%	==========================================================
%	FANCY PLOTTING
%	4. Random place, form, color, and size. A really cool plot ...
%	==========================================================

m = 100;
x = randn(m,1);
y = randn(m,1);
form = ceil(rand(m,1)*7); % note: 7 forms availible
color = rand(m,1);
ssize = rand(m,1)*4+1;

plotsym(x,y,form,color,ssize)

colormap(cool)

pause % Strike any key to continue. 
clc
% Thanks for your attention. Good bye.

echo off
